function [maxDiff, maxElem] = compare(x, y, msgText, DoShow, toler, dbg);
% Compare two vectors. Give error message if different
% -----------------------------------------------------------
% IN:
%   x,y         vectors to be compared. Matrices are flattened into vectors before
%               comparing.
%   msgText     text message to be displayed if vectors differ
%   DoShow      show vectors if different? Default = 0.
%   toler       tolerance for equality comparison. Default = 1e-6.
% OUT:
%   maxDiff     difference with max abs value (may be negative)
%   maxElem     element of max. difference
% REM:
%   for two nonzero elements, the difference is x/y-1 or y/x-1
%   for zero elements, the difference is x-y
%   y may be scalar

% TEST:     t_compar.m
% AUTHOR:   Lutz Hendricks, 1994
% ------------------------------------------------------------

    fName = 'COMPARE';
    smallC = 1e-7;
    if nargin < 3
        msgText = 'Difference in COMPARE.';
    end
    if nargin < 4
        DoShow = 0;
    end
    if nargin < 5
        toler = 1e-6;
    end
    if nargin < 6
       dbg = 0;
    end
    maxDiff = 11;
    maxElem = 1;


% **********  INPUT CHECK  ************

if dbg > 5
   % This is mainly to make sure that the arguments were not switched
   v_check( DoShow, 'i', [1,1], 0, 1 );
   v_check( toler,  'f', [1,1], 1e-12, 1 );

   if isempty(x)  |  isempty(y)
      warnmsg([ fName, ':  x or y empty.' ]);
      return;
   end
end


% ******************  MAIN  ************************

   if  any( size(y) ~= size(x) )
      if length(y) == 1
         y = y .* ones(size(x));
      else
         warnmsg([ fName, ':  Inputs of different sizes.' ], msgText);
         return;
      end
   end

   % Transform into vectors, if matrices
   x = x(:)';
   y = y(:)';
   n = length(x);


% ***************  COMPARE  *********************

   if any( abs([x,y]) < smallC )
      % element by element comparison to treat zero elements properly
      diff = x - y;
      for i = 1 : n
         if abs(y(i)) > smallC  &  abs(x(i)) > smallC
            diff(i) = diff(i) / y(i);
         end
      end
   else
      % No near zero values
      diff = x ./ y - 1;
   end

   [maxAbsDiff, tmp, maxElem] = maxidx(abs(diff));
   maxDiff = diff(maxElem);

   if maxAbsDiff > toler
       warnmsg(msgText, [ 'Max. difference: ', num2str(maxDiff) ]);
       if DoShow == 1
           disp(x);
           disp(y);
           disp(diff);
       end
   end

% *** end function ***
