function x = update(xN,xOld,GSweight, chngUp,chngDn, dbg)
% Update guess via Gauss Seidel formula.
% Limit changes.
% If sign changes are encountered: chngUp and -Dn are ignored.
% x = update(xN,xOld,GSweight, chngUp,chngDn)
% ---------------------------------------

% IN:
%   xN          new guess
%   xOld        previous guess
%   GSweight    updating weight
%   chngUp      max. x/xOld
%   chngDn      min. x/xOld

% OUT:
%   updated guess

% REM:
% - if any element of xOld is zero: ignore the constraint for ALL elements
% - if all xOld are small, ignore chngUp. This avoids getting stuck at a zero value.
% AUTHOR: Lutz Hendricks, 1995
% ---------------------------------------

   if nargin < 6
      dbg = 1;
   end

   if dbg > 10
      global UNDEFINED
      v_check( xOld, 'f', UNDEFINED,  UNDEFINED, UNDEFINED );
      v_check( xN,   'f', size(xOld), UNDEFINED, UNDEFINED );

      v_check( chngUp, 'f', [1,1], 1.00001, UNDEFINED );
      v_check( chngDn, 'f', [1,1], 0, 0.99999 );
      v_check( GSweight, 'f', [1,1], 1e-4, 0.9 );
   end

   % Check that sign the same
   if any( sign(xOld) ~= sign(xN) )
      signChange = 1;
   else
      signChange = 0;
   end


% ************  MAIN  ************

   xNew = xN * GSweight + xOld * (1-GSweight);

   if signChange == 1
      x = xNew;
      return
   end

   % ** Use bounds, but only if none of the special cases applies
   if chngUp > 0  &  chngDn > 0  &  all(xOld~=0)
      if any(xOld<0)
          xUp = chngUp.*xOld;
          xDn = chngDn.*xOld;
          x = max( min(xNew, max(xUp,xDn)), min(xUp,xDn) );
      else
          if all( xOld < 1e-4 )
             % Avoid getting stuck at a near zero value
             chngUp = 4;
          end
          x = max( min(xNew, chngUp.*xOld),  chngDn.*xOld );
      end
   else
       x = xNew;
   end

% *** end function ***

